import { Grid, Layout } from "antd";
import { SideMenuContent } from "../SideMenu";
import PageContent from "../PageContent";
import { useRef, useState } from "react";
import SideMenuMobile from "../SideMenu/Mobile";
import SideMenuDesktop from "../SideMenu/Desktop";

const { useBreakpoint } = Grid;

const Content = ({
  isSideMenuCollapsed,
  setIsSideMenuCollapsed,
  setUserSession,
  userSession,
  contentFirstRender,
}) => {
  return (
    <SideMenuContent
      isSideMenuCollapsed={isSideMenuCollapsed}
      setIsSideMenuCollapsed={setIsSideMenuCollapsed}
      setUserSession={setUserSession}
      userSession={userSession}
      contentFirstRender={contentFirstRender}
    />
  );
};

export default function DashboardLayout({ userSession, setUserSession }) {
  const screenBreakpoint = useBreakpoint();

  // open on desktop, closed on mobile on page open
  const [isSideMenuCollapsed, setIsSideMenuCollapsed] = useState(
    !screenBreakpoint.lg
  );
  // used to prevent auto close the sideMenu on mobile on first render as the the useEffect on the content component will be called after the first render
  const contentFirstRender = useRef(true);

  return (
    <Layout style={{ minHeight: "100vh" }}>
      <Layout>
        {screenBreakpoint.lg ? (
          <SideMenuDesktop
            isSideMenuCollapsed={
              screenBreakpoint.lg ? isSideMenuCollapsed : true
            }
            setIsSideMenuCollapsed={setIsSideMenuCollapsed}
          >
            <Content
              setIsSideMenuCollapsed={setIsSideMenuCollapsed}
              contentFirstRender={contentFirstRender}
            />
          </SideMenuDesktop>
        ) : (
          <SideMenuMobile
            isSideMenuCollapsed={isSideMenuCollapsed}
            setIsSideMenuCollapsed={setIsSideMenuCollapsed}
          >
            <Content
              setIsSideMenuCollapsed={setIsSideMenuCollapsed}
              contentFirstRender={contentFirstRender}
            />
          </SideMenuMobile>
        )}

        <PageContent
          isSideMenuCollapsed={isSideMenuCollapsed}
          setIsSideMenuCollapsed={setIsSideMenuCollapsed}
          userSession={userSession}
          setUserSession={setUserSession}
        />
      </Layout>
    </Layout>
  );
}
