import {
  Button,
  Col,
  Collapse,
  Drawer,
  Form,
  Input,
  Row,
  Segmented,
  Select,
  Space,
  Table,
  Tabs,
  Typography,
  notification,
  Badge,
  Popover,
} from "antd";
import { useTranslation } from "react-i18next";
import {
  AppStyle,
  Constants,
  FormatDatetime,
  myFetch,
  showUnkownErrorNotification,
  wsConnectionCustomEventName,
} from "../../utils";
import { useEffect, useRef, useState } from "react";
import {
  PlusOutlined,
  ChromeOutlined,
  SearchOutlined,
} from "@ant-design/icons";
import { t } from "i18next";
import { useCrmContext } from "../../Contexts/CrmContext";
import "@mdxeditor/editor/style.css";
import { MDXEditor } from "@mdxeditor/editor/MDXEditor";
import { headingsPlugin } from "@mdxeditor/editor/plugins/headings";
import { listsPlugin } from "@mdxeditor/editor/plugins/lists";
import { quotePlugin } from "@mdxeditor/editor/plugins/quote";
import { thematicBreakPlugin } from "@mdxeditor/editor/plugins/thematic-break";
import { toolbarPlugin } from "@mdxeditor/editor/plugins/toolbar";
import { BoldItalicUnderlineToggles } from "@mdxeditor/editor/plugins/toolbar/components/BoldItalicUnderlineToggles";
import { UndoRedo } from "@mdxeditor/editor/plugins/toolbar/components/UndoRedo";
import { linkPlugin } from "@mdxeditor/editor/plugins/link";
import { markdownShortcutPlugin } from "@mdxeditor/editor/plugins/markdown-shortcut";
import { MySupsenseFallback } from "../../Components/MySupsenseFallback";
import { linkDialogPlugin } from "@mdxeditor/editor";
import { tablePlugin } from "@mdxeditor/editor";
import { frontmatterPlugin } from "@mdxeditor/editor";
import { MyAvatar } from "../../Components/MyAvatar";
import { useAppContext } from "../../Contexts/AppContext";
import Highlighter from "react-highlight-words";

const CRM_TYPE = {
  CUSTOMERS: 0,
  DMC_PIPELINE: 1,
  SETTER_CLOSER: 2,
};

function MyBadge({ count, color = "blue" }) {
  return <Badge color={color} count={count} overflowCount={100000} showZero />;
}

const segmentedDmcPipelineBadgeColors = [
  "grey",
  "yellow",
  "purple",
  "blue",
  "orange",
  "green",
  "red",
];

const segmentedSetterCloserBadgeColors = [
  "grey",
  "yellow",
  "purple",
  "blue",
  "orange",
  "green",
  "red",
];

export default function CrmTest() {
  const { t } = useTranslation();
  const appContext = useAppContext();
  const crmContext = useCrmContext();

  const [isRequesting, setIsRequesting] = useState(false);

  const [isDrawerOpen, setIsDrawerOpen] = useState(false);
  const [notificationApi, notificationContextHolder] =
    notification.useNotification();

  // used for the segmented component on top of the page
  const [selectedSegmentedTypeValue, setSelectedSegmentedTypeValue] =
    useState(0);

  const filterAssignedEmployeeRef = useRef([]);

  const [searchText, setSearchText] = useState("");
  const [searchedColumn, setSearchedColumn] = useState("");
  const searchInput = useRef(null);

  const title =
    selectedSegmentedTypeValue === CRM_TYPE.CUSTOMERS
      ? "crm.customers.pageTitle"
      : selectedSegmentedTypeValue === CRM_TYPE.DMC_PIPELINE
      ? "crm.dmcPipeline.pageTitle"
      : "crm.setterCloser.pageTitle";

  const segmentedOptions = t(
    selectedSegmentedTypeValue === CRM_TYPE.DMC_PIPELINE
      ? "crm.dmcPipeline.segmentedOptions"
      : "crm.setterCloser.segmentedOptions",
    {
      returnObjects: true,
    }
  );

  const [
    selectedDmcPipelineSegmentedValue,
    setSelectedDmcPipelineSegmentedValue,
  ] = useState(0);
  const [
    selectedSetterCloserSegmentedValue,
    setSelectedSetterCloserSegmentedValue,
  ] = useState(0);

  const sorter = (a, b) => {
    if (a < b) {
      return -1;
    }
    if (a > b) {
      return 1;
    }
    return 0;
  };

  const handleSearch = (selectedKeys, confirm, dataIndex) => {
    confirm();
    setSearchText(selectedKeys[0]);
    setSearchedColumn(dataIndex);
  };
  const handleReset = (clearFilters) => {
    clearFilters();
    setSearchText("");
  };

  const getColumnSearchProps = (dataIndex) => ({
    filterDropdown: ({
      setSelectedKeys,
      selectedKeys,
      confirm,
      clearFilters,
      close,
    }) => (
      <div
        style={{
          padding: 8,
        }}
        onKeyDown={(e) => e.stopPropagation()}
      >
        <Input
          ref={searchInput}
          placeholder={`${t("crm.placeholderSearch")} ${dataIndex}`}
          value={selectedKeys[0]}
          onChange={(e) =>
            setSelectedKeys(e.target.value ? [e.target.value] : [])
          }
          onPressEnter={() => handleSearch(selectedKeys, confirm, dataIndex)}
          style={{
            marginBottom: 8,
            display: "block",
          }}
        />
        <Space>
          <Button
            type="primary"
            onClick={() => handleSearch(selectedKeys, confirm, dataIndex)}
            icon={<SearchOutlined />}
            size="small"
            style={{
              width: 90,
            }}
          >
            {t("common.button.search")}
          </Button>
          <Button
            onClick={() => clearFilters && handleReset(clearFilters)}
            size="small"
            style={{
              width: 100,
            }}
          >
            {t("common.button.reset")}
          </Button>
          <Button
            type="link"
            size="small"
            onClick={() => {
              confirm({
                closeDropdown: false,
              });
              setSearchText(selectedKeys[0]);
              setSearchedColumn(dataIndex);
            }}
          >
            {t("common.button.filter")}
          </Button>
          <Button
            type="link"
            size="small"
            onClick={() => {
              close();
            }}
          >
            {t("common.button.close")}
          </Button>
        </Space>
      </div>
    ),
    filterIcon: (filtered) => (
      <SearchOutlined
        style={{
          color: filtered ? "#1677ff" : undefined,
        }}
      />
    ),
    onFilter: (value, record) =>
      record[dataIndex].toString().toLowerCase().includes(value.toLowerCase()),
    onFilterDropdownOpenChange: (visible) => {
      if (visible) {
        setTimeout(() => searchInput.current?.select(), 100);
      }
    },
    render: (text) =>
      searchedColumn === dataIndex ? (
        <Highlighter
          highlightStyle={{
            backgroundColor: "#ffc069",
            padding: 0,
          }}
          searchWords={[searchText]}
          autoEscape
          textToHighlight={text ? text.toString() : ""}
        />
      ) : (
        text
      ),
  });

  const getTableContent = () => {
    return [
      {
        title: t("crm.table.assignedEmployee"),
        dataIndex: "assignedEmployee",
        key: "assignedEmployee",
        sorter: (a, b) => sorter(a._assignedEmployee, b._assignedEmployee),
        filters: filterAssignedEmployeeRef.current.map((item) => {
          return {
            text:
              appContext.users.find((u) => u.Id === item) !== undefined ? (
                <>
                  <MyAvatar userId={item} allUsers={appContext.users} />{" "}
                  {appContext.users.find((u) => u.Id === item)?.Username}
                </>
              ) : (
                item
              ),
            value: item,
          };
        }),
        onFilter: (value, record) => record._assignedEmployee === value,
        ellipsis: true,
      },
      {
        title: t("crm.table.firstName"),
        dataIndex: "firstName",
        key: "firstName",
        sorter: (a, b) => sorter(a.firstName, b.firstName),
        ...getColumnSearchProps("firstName"),
      },
      {
        title: t("crm.table.lastName"),
        dataIndex: "lastName",
        key: "lastName",
        sorter: (a, b) => sorter(a.lastName, b.lastName),
        ...getColumnSearchProps("lastName"),
      },
      {
        title: t("crm.table.company"),
        dataIndex: "company",
        key: "company",
        sorter: (a, b) => sorter(a.company, b.company),
        ...getColumnSearchProps("company"),
      },
      {
        title: t("crm.table.createdAt"),
        dataIndex: "createdAt",
        key: "createdAt",
        sorter: (a, b) => {
          return a.createdAt === Constants.TEXT_EMPTY_PLACEHOLDER
            ? 0
            : new Date(a.createdAt) - b.createdAt ===
              Constants.TEXT_EMPTY_PLACEHOLDER
            ? 0
            : new Date(b.createdAt);
        },
        sortDirections: ["descend"],
      },
      {
        title: t("crm.table.telephone"),
        dataIndex: "telephone",
        key: "telephone",
        sorter: (a, b) => sorter(a.telephone, b.telephone),
        ...getColumnSearchProps("telephone"),
      },
      {
        title: t("crm.table.email"),
        dataIndex: "email",
        key: "email",
        sorter: (a, b) => sorter(a.email, b.email),
        ...getColumnSearchProps("email"),
      },
      {
        title: t("crm.table.lastContact"),
        dataIndex: "lastContact",
        key: "lastContact",
        sorter: (a, b) => a.lastContact.length - b.lastContact.length,
        sortDirections: ["descend"],
      },
      {
        title: t("crm.table.createdBy"),
        dataIndex: "createdBy",
        key: "createdBy",
        sorter: (a, b) => a.createdBy - b.createdBy,
        sortDirections: ["descend"],
      },
    ];
  };

  const getTableItems = () => {
    let data = crmContext.customers;
    let items = [];

    if (selectedSegmentedTypeValue === CRM_TYPE.DMC_PIPELINE) {
      data = data.filter((item) => item.Pipeline === 1);
      data = data.filter(
        (item) => item.DealPhase === selectedDmcPipelineSegmentedValue + 1
      );
    } else if (selectedSegmentedTypeValue === CRM_TYPE.SETTER_CLOSER) {
      data = data.filter((item) => item.Pipeline === 2);
      data = data.filter(
        (item) => item.DealPhase === selectedSetterCloserSegmentedValue + 1
      );
    }

    data.forEach((item) => {
      items.push({
        key: item.Id,
        _assignedEmployee: item.AssignedEmployee,
        assignedEmployee: (
          <>
            <Popover
              placement="right"
              trigger="hover"
              content={
                <MyAvatar
                  userId={item.AssignedEmployee}
                  allUsers={appContext.users}
                  avatarWidth={256}
                />
              }
            >
              <>
                <MyAvatar
                  userId={item.AssignedEmployee}
                  allUsers={appContext.users}
                />{" "}
                {
                  appContext.users.find((u) => u.Id === item.AssignedEmployee)
                    ?.Username
                }
              </>
            </Popover>
          </>
        ),
        id: item.Id,
        firstName: item.FirstName,
        lastName: item.LastName,
        company: item.Company,
        createdAt: FormatDatetime(item.CreatedAt),
        telephone: item.Telephone,
        email: item.Email,
        lastContact: FormatDatetime(item.LastContact),
        createdBy: (
          <>
            <Popover
              placement="right"
              trigger="hover"
              content={
                <MyAvatar
                  userId={item.CreatedBy}
                  allUsers={appContext.users}
                  avatarWidth={256}
                />
              }
            >
              <>
                <MyAvatar userId={item.CreatedBy} allUsers={appContext.users} />{" "}
                {
                  appContext.users.find((u) => u.Id === item.CreatedBy)
                    ?.Username
                }
              </>
            </Popover>
          </>
        ),
      });
    });

    return items;
  };

  const getSegmentedLabels = (item, index) => {
    return (
      <Space>
        <span>{item}</span>
        <MyBadge
          count={
            crmContext.customers.filter(
              (customer) =>
                customer.Pipeline ===
                  (selectedSegmentedTypeValue === CRM_TYPE.DMC_PIPELINE
                    ? 1
                    : 2) && customer.DealPhase === index + 1
            ).length
          }
          color={
            selectedSegmentedTypeValue === CRM_TYPE.DMC_PIPELINE
              ? segmentedDmcPipelineBadgeColors[index]
              : segmentedSetterCloserBadgeColors[index]
          }
        />
      </Space>
    );
  };

  useEffect(() => {
    const customersRequest = () => {
      setIsRequesting(true);

      myFetch(`/crm/customers`, "GET").then((data) => {
        if (data === undefined || data === null) return;

        data.forEach((item) => {
          if (
            !filterAssignedEmployeeRef.current.includes(item.AssignedEmployee)
          ) {
            filterAssignedEmployeeRef.current.push(item.AssignedEmployee);
          }
        });

        crmContext.setCustomers(data);
        setIsRequesting(false);
      });
    };

    customersRequest();

    const handleCustomersRequest = () => customersRequest();

    document.addEventListener(
      wsConnectionCustomEventName,
      handleCustomersRequest
    );

    return () =>
      document.removeEventListener(
        wsConnectionCustomEventName,
        handleCustomersRequest
      );
  }, []);

  return (
    <>
      {notificationContextHolder}

      <Segmented
        value={selectedSegmentedTypeValue}
        onChange={(value) => {
          setSelectedSegmentedTypeValue(value);
        }}
        options={[
          {
            value: CRM_TYPE.CUSTOMERS,
            label: (
              <Space>
                <span>All Leads</span>
                <MyBadge count={crmContext.customers.length} />
              </Space>
            ),
          },
          {
            value: CRM_TYPE.DMC_PIPELINE,
            label: (
              <Space>
                <span>DMC Pipeline</span>
                <MyBadge
                  count={
                    crmContext.customers.filter((item) => item.Pipeline === 1)
                      .length
                  }
                />
              </Space>
            ),
          },
          {
            value: CRM_TYPE.SETTER_CLOSER,
            label: (
              <Space>
                <span>Setter / Closer</span>
                <MyBadge
                  count={
                    crmContext.customers.filter((item) => item.Pipeline === 2)
                      .length
                  }
                />
              </Space>
            ),
          },
        ]}
        block
      />

      <div
        style={{
          display: "flex",
          justifyContent: "space-between",
          marginTop: 6,
        }}
      >
        <Typography.Title level={4}>{t(title)}</Typography.Title>

        <Button
          type="primary"
          icon={<PlusOutlined />}
          onClick={() => {
            crmContext.openDrawerCustomerId.current = "new";
            crmContext.currentDrawerCustomerRef.current = null;

            setIsDrawerOpen(true);
          }}
        >
          {t("crm.buttonNew")}
        </Button>
      </div>

      {selectedSegmentedTypeValue !== CRM_TYPE.CUSTOMERS ? (
        <Segmented
          value={
            selectedSegmentedTypeValue === CRM_TYPE.DMC_PIPELINE
              ? selectedDmcPipelineSegmentedValue
              : selectedSetterCloserSegmentedValue
          }
          onChange={(value) => {
            if (selectedSegmentedTypeValue === CRM_TYPE.DMC_PIPELINE) {
              setSelectedDmcPipelineSegmentedValue(value);
            } else {
              setSelectedSetterCloserSegmentedValue(value);
            }
          }}
          options={segmentedOptions.map((item, index) => {
            return {
              value: index,
              label: getSegmentedLabels(item, index),
            };
          })}
          style={{ marginBottom: AppStyle.app.margin }}
        />
      ) : (
        <div style={{ height: 44 }} />
      )}

      <Table
        scroll={{ x: "max-content" }}
        columns={getTableContent()}
        dataSource={getTableItems()}
        loading={isRequesting}
        pagination
        onRow={(record) => {
          return {
            onClick: () => {
              setIsDrawerOpen(true);
              crmContext.openDrawerCustomerId.current = record.id;
            },
          };
        }}
      />

      <CustomerDrawer
        isOpen={isDrawerOpen}
        setIsOpen={setIsDrawerOpen}
        onClose={() => setIsDrawerOpen(false)}
        notificationApi={notificationApi}
      />
    </>
  );
}

function CustomerDrawer({ isOpen, setIsOpen, onClose, notificationApi }) {
  const { t } = useTranslation();
  const appContext = useAppContext();
  const crmContext = useCrmContext();

  const [formDealInfo] = Form.useForm();

  const tabItems = [
    {
      key: "0",
      label: t("crm.tabs.dealInfo"),
      children: <TabContentDealInfo form={formDealInfo} />,
    },
    {
      key: "1",
      label: t("crm.tabs.activities"),
      children: <TabContentActivities />,
    },
    {
      key: "2",
      label: t("crm.tabs.notes"),
      children: (
        <TabContentNotes
          notes={
            crmContext.currentDrawerCustomerRef.current === null ||
            crmContext.currentDrawerCustomerRef.current.Notes === null
              ? ""
              : crmContext.currentDrawerCustomerRef.current.Notes
          }
        />
      ),
    },
  ];

  const [activeTab, setActiveTab] = useState(tabItems[0].key);

  const customerRequest = () => {
    if (!isOpen) return;

    myFetch(
      `/crm/customer/view/${crmContext.openDrawerCustomerId.current}`,
      "GET"
    ).then((data) => {
      crmContext.currentDrawerCustomerRef.current = data;

      formDealInfo.setFieldsValue({
        Pipeline: data.Pipeline,
        DealPhase: data.DealPhase,
        FirstName: data.FirstName,
        LastName: data.LastName,
        Telephone: data.Telephone,
        Email: data.Email,
        Company: data.Company,
        ZipCode: data.ZipCode,
        Address: data.Address,
        City: data.City,
        Country: data.Country,
        FederalState: data.FederalState,
        Website: data.Website,
        LeadOrigin: data.LeadOrigin,
        NumberOfEmployees: data.NumberOfEmployees,
        NumberOfJobsSearchedFor: data.NumberOfJobsSearchedFor,
        JobTitle: data.JobTitle,
        NumberOfEmployeesRequired: data.NumberOfEmployeesRequired,
        HowLongHadHeBeenSearching: data.HowLongHadHeBeenSearching,
        Turnover: data.Turnover,
        DateOfcompletion: data.DateOfcompletion,
        OrderVolume: data.OrderVolume,
        NumberOfInstallments: data.NumberOfInstallments,
        AmountsOfTheInstallments: data.AmountsOfTheInstallments,
        BookedPackages: data.BookedPackages,
        AssignedEmployee: data.AssignedEmployee,
      });
    });
  };

  const handleRequestError = (status) => {
    if (status === 409) {
      notificationApi["error"]({
        message: t("crm.tabContent.request.duplicateCompanyError.message"),
        description: t(
          "crm.tabContent.request.duplicateCompanyError.description"
        ),
      });
    } else {
      showUnkownErrorNotification(notificationApi, t);
    }

    setIsOpen(true);
  };

  useEffect(() => {
    // set the active tab to the first one if the drawer is closed
    if (!isOpen) {
      setActiveTab(tabItems[0].key);
    }

    if (crmContext.openDrawerCustomerId.current === null) return;

    formDealInfo
      .validateFields()
      .then((values) => {
        if (crmContext.openDrawerCustomerId.current === "new") {
          if (isOpen) {
            formDealInfo.resetFields();

            formDealInfo.setFieldsValue({
              Pipeline: 1,
              DealPhase: 1,
              AssignedEmployee: appContext.userId.current,
            });
            return;
          }

          let changedFields = [];
          let newCustomer = {};

          Object.keys(values).forEach((key) => {
            if (values[key] !== undefined) {
              changedFields.push(key);
            }
          });

          // check notes

          if (crmContext.currentDrawerCustomerNotesRef.current !== null) {
            changedFields.push("Notes");
          }

          // check if something has changed (length 2 = only the pipeline, deal phase and assigned employee)
          if (changedFields.length === 3) return;

          Object.keys(values).forEach((key) => {
            if (values[key] !== undefined) {
              newCustomer[key] = values[key];
            }
          });

          if (changedFields.includes("Notes")) {
            newCustomer.Notes =
              crmContext.currentDrawerCustomerNotesRef.current;
          }

          myFetch(`/crm/customer/create`, "POST", newCustomer)
            .then(() => {
              crmContext.openDrawerCustomerId.current = false;
              handleCloseDrawer();
            })
            .catch((status) => handleRequestError(status));
          return;
        }

        if (isOpen) {
          customerRequest();
        } else {
          let changedFields = [];
          const updatedCustomer = {};

          Object.keys(values).forEach((key) => {
            if (
              values[key] !== crmContext.currentDrawerCustomerRef.current[key]
            ) {
              changedFields.push(key);
            }
          });

          // check notes

          if (
            crmContext.currentDrawerCustomerNotesRef.current !== null &&
            crmContext.currentDrawerCustomerNotesRef.current !==
              crmContext.currentDrawerCustomerRef.current.Notes
          ) {
            changedFields.push("Notes");
          }

          // check if something has changed
          if (changedFields.length > 0) {
            changedFields.forEach((key) => {
              updatedCustomer[key] = values[key];
            });

            if (changedFields.includes("Notes")) {
              updatedCustomer.Notes =
                crmContext.currentDrawerCustomerNotesRef.current;
            }

            myFetch(
              `/crm/customer/update/${crmContext.openDrawerCustomerId.current}`,
              "POST",
              updatedCustomer
            )
              .then(() => handleCloseDrawer())
              .catch((status) => handleRequestError(status));
          }
        }
      })
      .catch((err) => console.log("error", err));

    const handleCustomerRequest = () => customerRequest();

    document.addEventListener(
      wsConnectionCustomEventName,
      handleCustomerRequest
    );

    return () =>
      document.removeEventListener(
        wsConnectionCustomEventName,
        handleCustomerRequest
      );
  }, [isOpen]);

  const handleCloseDrawer = () => {
    crmContext.openDrawerCustomerId.current = null;
    crmContext.currentDrawerCustomerRef.current = null;
    crmContext.currentDrawerCustomerNotesRef.current = null;

    formDealInfo.resetFields();
  };

  return (
    <Drawer
      placement="right"
      open={isOpen}
      onClose={onClose}
      width={720}
      extra={
        <Space>
          <Form form={formDealInfo} layout="inline">
            <Form.Item name="AssignedEmployee">
              <Select style={{ minWidth: 100 }}>
                {appContext.users.map((user) => (
                  <Select.Option key={user.Id} value={user.Id}>
                    <Space>
                      <MyAvatar
                        userId={user.Id}
                        allUsers={appContext.users}
                        avatarWidth={24}
                      />

                      {user.Username}
                    </Space>
                  </Select.Option>
                ))}
              </Select>
            </Form.Item>
          </Form>

          <Button
            onClick={() => {
              onClose();
              handleCloseDrawer();
            }}
          >
            {t("crm.buttonUndo")}
          </Button>
        </Space>
      }
    >
      <Tabs
        activeKey={activeTab}
        onChange={(activeKey) => setActiveTab(activeKey)}
        items={tabItems}
        centered
      />
    </Drawer>
  );
}

function Content({ children }) {
  return (
    <Row gutter={16}>
      <Col xs={24} sm={12}>
        {children[0]}
      </Col>
      <Col xs={24} sm={12}>
        {children[1]}
      </Col>
    </Row>
  );
}

function CollapseContainer({ children, label }) {
  return (
    <Collapse
      defaultActiveKey="1"
      items={[
        {
          key: "1",
          label: label,
          children: children,
        },
      ]}
    />
  );
}

function TabContentDealInfo({ form }) {
  const pipeline = Form.useWatch("Pipeline", form);
  const dealPhase = Form.useWatch("DealPhase", form);

  const FormItem = ({ name, label }) => (
    <Form.Item name={name} label={typeof label === "string" ? t(label) : label}>
      <Input maxLength={250} />
    </Form.Item>
  );

  const ContentBlock = ({ items }) => {
    // Split items into chunks of two
    const chunks = [];

    for (let i = 0; i < items.length; i += 2) {
      chunks.push(items.slice(i, i + 2));
    }

    // Render a Content component for each chunk
    return (
      <>
        {chunks.map((chunk, index) => (
          <Content key={index}>
            {chunk.map((item) => (
              <FormItem key={item.name} {...item} />
            ))}
          </Content>
        ))}
      </>
    );
  };

  const CollapseContainerBlock = ({ label, items }) => (
    <CollapseContainer label={t(label)}>
      <ContentBlock items={items} />
    </CollapseContainer>
  );

  // set deal phase to 1 when the pipeline changes
  // without this the user could set a deal phase that is not available for the selected pipeline
  useEffect(() => {
    const options = t(
      pipeline === 1
        ? "crm.dmcPipeline.segmentedOptions"
        : "crm.setterCloser.segmentedOptions",
      { returnObjects: true }
    );

    if (dealPhase > options.length) {
      form.setFieldsValue({
        DealPhase: options.length,
      });
    }
  }, [pipeline]);

  return (
    <MySupsenseFallback>
      <Form form={form} layout="vertical">
        <Space direction="vertical" style={{ display: "flex" }}>
          <CollapseContainer
            label={t("crm.tabContent.dealInfo.collapseDealStatus.label")}
          >
            <Content>
              <Form.Item
                name="Pipeline"
                label={t("crm.tabContent.dealInfo.collapseDealStatus.pipeline")}
              >
                <Select
                  options={[
                    {
                      value: 1,
                      label: t("crm.dmcPipeline.pageTitle"),
                    },
                    {
                      value: 2,
                      label: t("crm.setterCloser.pageTitle"),
                    },
                  ]}
                />
              </Form.Item>

              <Form.Item
                name="DealPhase"
                label={t(
                  "crm.tabContent.dealInfo.collapseDealStatus.dealPhase"
                )}
              >
                <Select
                  options={t(
                    pipeline === 1
                      ? "crm.dmcPipeline.segmentedOptions"
                      : "crm.setterCloser.segmentedOptions",
                    { returnObjects: true }
                  ).map((item, index) => {
                    return {
                      value: index + 1,
                      label: item,
                    };
                  })}
                />
              </Form.Item>
            </Content>
          </CollapseContainer>

          <CollapseContainerBlock
            label="crm.tabContent.dealInfo.collapseMasterDataOfContact.label"
            items={[
              {
                name: "FirstName",
                label:
                  "crm.tabContent.dealInfo.collapseMasterDataOfContact.firstName",
              },
              {
                name: "LastName",
                label:
                  "crm.tabContent.dealInfo.collapseMasterDataOfContact.lastName",
              },
              {
                name: "Telephone",
                label:
                  "crm.tabContent.dealInfo.collapseMasterDataOfContact.telephone",
              },
              {
                name: "Email",
                label:
                  "crm.tabContent.dealInfo.collapseMasterDataOfContact.email",
              },
              {
                name: "Company",
                label:
                  "crm.tabContent.dealInfo.collapseMasterDataOfContact.company",
              },
              {
                name: "ZipCode",
                label:
                  "crm.tabContent.dealInfo.collapseMasterDataOfContact.zipCode",
              },
              {
                name: "Address",
                label:
                  "crm.tabContent.dealInfo.collapseMasterDataOfContact.address",
              },
              {
                name: "City",
                label:
                  "crm.tabContent.dealInfo.collapseMasterDataOfContact.city",
              },
              {
                name: "Country",
                label:
                  "crm.tabContent.dealInfo.collapseMasterDataOfContact.country",
              },
              {
                name: "FederalState",
                label:
                  "crm.tabContent.dealInfo.collapseMasterDataOfContact.federalState",
              },
              {
                name: "Website",
                label: (
                  <Space>
                    <span>
                      {t(
                        "crm.tabContent.dealInfo.collapseMasterDataOfContact.website"
                      )}
                    </span>

                    <ChromeOutlined
                      style={{ color: AppStyle.app.primary }}
                      onClick={() => {
                        const website = form.getFieldValue("Website");

                        if (
                          !website.startsWith("http://") &&
                          !website.startsWith("https://")
                        )
                          return;

                        window.open(
                          form.getFieldValue("Website"),
                          "_blank",
                          "noopener"
                        );
                      }}
                    />
                  </Space>
                ),
              },
              {
                name: "LeadOrigin",
                label:
                  "crm.tabContent.dealInfo.collapseMasterDataOfContact.leadOrigin",
              },
            ]}
          />

          <CollapseContainerBlock
            label="crm.tabContent.dealInfo.collapseSetterInfo.label"
            items={[
              {
                name: "NumberOfEmployees",
                label:
                  "crm.tabContent.dealInfo.collapseSetterInfo.numberOfEmployees",
              },
              {
                name: "NumberOfJobsSearchedFor",
                label:
                  "crm.tabContent.dealInfo.collapseSetterInfo.numberOfJobsSearchedFor",
              },
              {
                name: "JobTitle",
                label: "crm.tabContent.dealInfo.collapseSetterInfo.jobTitle",
              },
              {
                name: "NumberOfEmployeesRequired",
                label:
                  "crm.tabContent.dealInfo.collapseSetterInfo.numberOfEmployeesRequired",
              },
              {
                name: "HowLongHadHeBeenSearching",
                label:
                  "crm.tabContent.dealInfo.collapseSetterInfo.howLongHadHeBeenSearching",
              },
              {
                name: "Turnover",
                label: "crm.tabContent.dealInfo.collapseSetterInfo.turnover",
              },
            ]}
          />

          <CollapseContainerBlock
            label="crm.tabContent.dealInfo.collapseDealProperties.label"
            items={[
              {
                name: "DateOfcompletion",
                label:
                  "crm.tabContent.dealInfo.collapseDealProperties.dateOfcompletion",
              },
              {
                name: "OrderVolume",
                label:
                  "crm.tabContent.dealInfo.collapseDealProperties.orderVolume",
              },
              {
                name: "NumberOfInstallments",
                label:
                  "crm.tabContent.dealInfo.collapseDealProperties.numberOfInstallments",
              },
              {
                name: "AmountsOfTheInstallments",
                label:
                  "crm.tabContent.dealInfo.collapseDealProperties.amountsOfTheInstallments",
              },
              {
                name: "BookedPackages",
                label:
                  "crm.tabContent.dealInfo.collapseDealProperties.bookedPackages",
              },
            ]}
          />
        </Space>
      </Form>
    </MySupsenseFallback>
  );
}

function TabContentActivities() {
  return (
    <MySupsenseFallback>
      <div>Coming soon</div>
    </MySupsenseFallback>
  );
}

function TabContentNotes({ notes }) {
  const crmContext = useCrmContext();

  return (
    <MySupsenseFallback>
      <MDXEditor
        key={crmContext.currentDrawerCustomerRef.current?.Id}
        className="mdx-editor"
        markdown={notes}
        onChange={(value) => {
          crmContext.currentDrawerCustomerNotesRef.current = value;
        }}
        plugins={[
          listsPlugin(),
          quotePlugin(),
          headingsPlugin(),
          linkPlugin(),
          linkDialogPlugin(),
          tablePlugin(),
          thematicBreakPlugin(),
          frontmatterPlugin(),
          markdownShortcutPlugin(),
          toolbarPlugin({
            toolbarContents: () => (
              <>
                <UndoRedo />
                <BoldItalicUnderlineToggles />
              </>
            ),
          }),
        ]}
      />
    </MySupsenseFallback>
  );
}
