import { useEffect, useState } from "react";
import MyQrScanner from "../../Components/MyQrScanner";
import { useWebSocketContext } from "../../Contexts/WebSocketContext";
import { SentMessagesCommands } from "../../Handlers/WebSocketMessageHandler";
import { BrowserTabSession } from "../../utils";
import { Checkbox, Space } from "antd";
import { useScannerContext } from "../../Contexts/ScannerContext";
import { t } from "i18next";

export default function Scanners() {
  const webSocketContext = useWebSocketContext();
  const scannerContext = useScannerContext();

  const [isScannerActive, setIsScannerActive] = useState(false);

  useEffect(() => {
    // update automatic filling inputs checkbox if it was updated in another browser tab
    const lCheckboxAutomaticFillingOfInputFieldsChecked =
      localStorage.getItem("cAFOIF");

    if (
      lCheckboxAutomaticFillingOfInputFieldsChecked !==
      scannerContext.checkboxControlByScannerChecked
    ) {
      scannerContext.setCheckboxAutomaticFillingOfInputFieldsChecked(
        lCheckboxAutomaticFillingOfInputFieldsChecked === "true" ? true : false
      );
    }

    // update automatic recognition of equipment documentation checkbox if it was updated in another browser tab
    const lCheckboxAutomaticRecognitionOfEquipmentDocumentationChecked =
      localStorage.getItem("cAROED") === "true";

    if (
      lCheckboxAutomaticRecognitionOfEquipmentDocumentationChecked !==
      scannerContext.checkboxAutomaticRecognitionOfEquipmentDocumentationChecked
    ) {
      scannerContext.setCheckboxAutomaticRecognitionOfEquipmentDocumentationChecked(
        lCheckboxAutomaticRecognitionOfEquipmentDocumentationChecked
      );
    }
  }, []);

  return (
    <>
      <MyQrScanner
        isScannerActive={isScannerActive}
        setIsScannerActive={setIsScannerActive}
        previewTitle={t("scanner.title")}
        onDecode={(result) => {
          webSocketContext.SendSocketMessage(
            SentMessagesCommands.ScannerNewScan,
            { Scan: result, BrowserTabSession: BrowserTabSession }
          );

          setIsScannerActive(false);
        }}
        onError={(error) => console.error(error?.message)}
        bottomContent={
          <Space direction="vertical" style={{ textAlign: "left" }}>
            <Checkbox
              checked={
                scannerContext.checkboxAutomaticFillingOfInputFieldsChecked
              }
              onChange={(e) =>
                scannerContext.setCheckboxAutomaticFillingOfInputFieldsChecked(
                  e.target.checked
                )
              }
            >
              {t("scanner.checkbox.automaticFillingOfInputFields")}
            </Checkbox>

            <Checkbox
              checked={
                scannerContext.checkboxAutomaticRecognitionOfEquipmentDocumentationChecked
              }
              onChange={(e) =>
                scannerContext.setCheckboxAutomaticRecognitionOfEquipmentDocumentationChecked(
                  e.target.checked
                )
              }
            >
              {t(
                "scanner.checkbox.automaticRecognitionOfEquipmentDocumentation"
              )}
            </Checkbox>
          </Space>
        }
      />
    </>
  );
}

/*const webSocketContext = useWebSocketContext()
  const { t } = useTranslation();

  const getTableColumns = () => {
    return [
      {
        title: t("scanners.column.name"),
        dataIndex: "name",
        key: "name",
      },
      {
        title: t("scanners.column.usedBy"),
        dataIndex: "usedByUserId",
        key: "usedByUserId",
      },
      {
        title: t("scanners.column.lastUsed"),
        dataIndex: "lastUsed",
        key: "lastUsed",
      },
      {
        title: t("scanners.column.registeredAt"),
        dataIndex: "registeredAt",
        key: "registeredAt",
      },
      {
        title: t("scanners.column.userAgent"),
        dataIndex: "userAgent",
        key: "userAgent",
      },
      {
        title: t("scanners.column.action.title"),
        dataIndex: "action",
        key: "action",
        render: (_, record) => (
          <Space size="middle">
            {record._usedByUserId === getUserId() ? (
              <Popconfirm
                placement="left"
                title={t("scanners.column.action.disconnect.popconfirm.title")}
                okText={t(
                  "scanners.column.action.disconnect.popconfirm.okText"
                )}
                cancelText={t("common.button.cancel")}
                onConfirm={() => {
                  webSocketContext.SendSocketMessage(
                    SentMessagesCommands.ScannersDisconnectScanner,
                    {
                      ScannerId: record.key,
                    }
                  );
                }}
              >
                <Link to="#">
                  {t("scanners.column.action.disconnect.link")}
                </Link>
              </Popconfirm>
            ) : (
              <Popconfirm
                placement="left"
                title={t("scanners.column.action.use.popconfirm.title")}
                description={t(
                  "scanners.column.action.use.popconfirm.description"
                )}
                okText={t("scanners.column.action.use.popconfirm.okText")}
                cancelText={t("common.button.cancel")}
                onConfirm={() => {
                  webSocketContext.SendSocketMessage(
                    SentMessagesCommands.ScannersUseScanners,
                    {
                      ScannerId: record.key,
                    }
                  );
                }}
              >
                <Link to="#">{t("scanners.column.action.use.link")}</Link>
              </Popconfirm>
            )}
          </Space>
        ),
      },
    ];
  };

  const getTableItems = () => {
    if (webSocketContext.Scanners === null) return [];

    let items = [];

    webSocketContext.Scanners.forEach((scanner) => {
      const usedByUser = webSocketContext.AllUsers.find(
        (user) => user.Id === scanner.UsedByUserId
      );

      items.push({
        key: scanner.Id,
        name: scanner.Name,
        usedByUserId:
          scanner.UsedByUserId === "" ? (
            Constants.TEXT_EMPTY_PLACEHOLDER
          ) : (
            <>
              <MyAvatar avatar={usedByUser.Avatar} />
              <span> {usedByUser.Username}</span>
            </>
          ),
        _usedByUserId: scanner.UsedByUserId,
        lastUsed: FormatDatetime(scanner.LastUsed),
        registeredAt: FormatDatetime(scanner.RegisteredAt),
        userAgent: scanner.UserAgent,
      });
    });

    return items;
  };

  return (
    <>
      <Typography.Title level={4}>
        {t("scanners.header.scanners")} (
        {webSocketContext.Scanners === null
          ? "0"
          : webSocketContext.Scanners.length}
        )
      </Typography.Title>

      <Table
        scroll={{ x: "max-content" }}
        columns={getTableColumns()}
        dataSource={getTableItems()}
      />
    </>
  ); */
